
***************
Getting started
***************


Installation
------------

.. grid:: 2

    .. grid-item-card:: Installing with conda
       :text-align: center
       :columns: 12


       .. code-block:: bash

          conda create -n anchor -c conda-forge anchor-annotator

       +++

       .. button-ref:: installation
          :expand:
          :color: primary
          :ref-type: doc

          To the installation guide


    .. grid-item-card:: Running anchor
       :text-align: center

       .. code-block:: bash

          conda activate anchor
          mfa anchor

       +++

       .. button-ref:: user_guide
          :expand:
          :color: primary

          User guide


    .. grid-item-card:: First steps
       :text-align: center

       First time using Anchor? Want a walk-through of a specific use case?

       +++

       .. button-ref:: first_steps
          :expand:
          :color: primary

          First steps


.. toctree::
   :maxdepth: 1
   :hidden:

   installation
   first_steps/index
